@@ -1,6 +1,9 @@
-from widgets import FullScreenTextarea
+try:
+    from widgets import FullScreenTextarea
+except ImportError:
+    pass
 
-VERSION = (1, 1, 2)
+VERSION = (1, 1, 3)
 
 
 def get_version():
